@@ -12,15 +12,16 @@
 #'
 #' @export
 fix_mobile <- function(x) {
-  if (is.numeric(x)) {
-    # options(scipen = 999)
-    x <- as.character(x)
+  if (!is.character(x)) {
+    if (is.numeric(x))
+      x <- as.character(x)
+    else
+      stop(sprintf("Objects of type %s are not supported", sQuote(typeof(x))))
   }
   # Remove entries that are beyond redemption i.e. too long or too short
   x <- ifelse(nchar(x) > 11 | nchar(x) < 10, NA_character_, x)
   
   # Add a leading '0' if there are 10 digits
-  x <- as.character(x)
   x <- sub("(^[0-9]{10}$)", "0\\1", x)
   
   # Remove those that still don't look like local mobile numbers (NG)
